@@ -1,7 +1,7 @@
 """
 Type annotations for dynamodb service type definitions.
 
-[Open documentation](./type_defs.md)
+[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/type_defs.html)
 
 Usage::
 
